@@ -20,17 +20,17 @@ import dateutil
 from dagster import (
     AssetKey,
     AssetsDefinition,
+    AutoMaterializePolicy,
     FreshnessPolicy,
     In,
     OpExecutionContext,
     Out,
     PartitionsDefinition,
+    PermissiveConfig,
     _check as check,
     get_dagster_logger,
     op,
 )
-from dagster._config.field import Field
-from dagster._config.field_utils import Permissive
 from dagster._core.definitions.events import (
     AssetMaterialization,
     AssetObservation,
@@ -45,15 +45,18 @@ from dagster._utils.merger import deep_merge_dicts
 
 from dagster_dbt.asset_utils import (
     default_asset_key_fn,
+    default_auto_materialize_policy_fn,
     default_freshness_policy_fn,
     default_group_fn,
     default_metadata_fn,
     get_asset_deps,
     get_deps,
 )
-from dagster_dbt.cli.resources import DbtCliResource
-from dagster_dbt.cli.types import DbtCliOutput
-from dagster_dbt.cli.utils import execute_cli
+from dagster_dbt.core.resources import DbtCliClient
+from dagster_dbt.core.resources_v2 import DbtCli, DbtManifest
+from dagster_dbt.core.types import DbtCliOutput
+from dagster_dbt.core.utils import build_command_args_from_flags, execute_cli
+from dagster_dbt.errors import DagsterDbtError
 from dagster_dbt.types import DbtOutput
 from dagster_dbt.utils import (
     ASSET_RESOURCE_TYPES,
@@ -94,20 +97,25 @@ def _load_manifest_for_project(
         return json.load(f), cli_output
 
 
-def _can_stream_events(dbt_resource: DbtCliResource) -> bool:
+def _can_stream_events(dbt_resource: Union[DbtCliClient, DbtCli]) -> bool:
     """Check if the installed dbt version supports streaming events."""
     import dbt.version
     from packaging import version
 
-    return (
-        version.parse(dbt.version.__version__) >= version.parse("1.4.0")
-        and dbt_resource._json_log_format  # noqa: SLF001
-    )
+    if version.parse(dbt.version.__version__) >= version.parse("1.4.0"):
+        # The json log format is required for streaming events. DbtCli always uses this format, but
+        # DbtCliClient has an option to disable it.
+        if isinstance(dbt_resource, DbtCli):
+            return True
+        else:
+            return dbt_resource._json_log_format  # noqa: SLF001
+    else:
+        return False
 
 
 def _batch_event_iterator(
     context: OpExecutionContext,
-    dbt_resource: DbtCliResource,
+    dbt_resource: DbtCliClient,
     use_build_command: bool,
     node_info_to_asset_key: Callable[[Mapping[str, Any]], AssetKey],
     runtime_metadata_fn: Optional[
@@ -118,6 +126,9 @@ def _batch_event_iterator(
     """Yields events for a dbt cli invocation. Waits until the entire command has completed before
     emitting outputs.
     """
+    # clean up any run results from the last run
+    dbt_resource.remove_run_results_json()
+
     dbt_output: Optional[DbtOutput] = None
     try:
         if use_build_command:
@@ -197,7 +208,7 @@ def _events_for_structured_json_line(
             output_name=output_name_fn(compiled_node_info),
             metadata=metadata,
         )
-    elif node_resource_type == "test" and runtime_node_info.get("node_finished_at") is not None:
+    elif node_resource_type == "test" and runtime_node_info.get("node_finished_at"):
         upstream_unique_ids = (
             manifest_json["nodes"][unique_id].get("depends_on", {}).get("nodes", [])
         )
@@ -221,26 +232,61 @@ def _events_for_structured_json_line(
 
 def _stream_event_iterator(
     context: OpExecutionContext,
-    dbt_resource: DbtCliResource,
+    dbt_resource: Union[DbtCli, DbtCliClient],
     use_build_command: bool,
     node_info_to_asset_key: Callable[[Mapping[str, Any]], AssetKey],
     runtime_metadata_fn: Optional[
         Callable[[OpExecutionContext, Mapping[str, Any]], Mapping[str, RawMetadataValue]]
     ],
     kwargs: Dict[str, Any],
+    manifest_json: Mapping[str, Any],
 ) -> Iterator[Union[AssetObservation, Output]]:
     """Yields events for a dbt cli invocation. Emits outputs as soon as the relevant dbt logs are
     emitted.
     """
-    manifest_json = check.not_none(dbt_resource.get_manifest_json())
+    if isinstance(dbt_resource, DbtCliClient):
+        for parsed_json_line in dbt_resource.cli_stream_json(
+            command="build" if use_build_command else "run",
+            **kwargs,
+        ):
+            yield from _events_for_structured_json_line(
+                parsed_json_line,
+                context,
+                node_info_to_asset_key,
+                runtime_metadata_fn,
+                manifest_json,
+            )
+    else:
+        if runtime_metadata_fn is not None:
+            raise DagsterDbtError(
+                "The runtime_metadata_fn argument on the load_assets_from_dbt_manifest and"
+                " load_assets_from_dbt_project functions is not supported when using the DbtCli"
+                " resource. Use the @dbt_assets decorator instead if you want control over what"
+                " metadata is yielded at runtime."
+            )
 
-    for parsed_json_line in dbt_resource.cli_stream_json(
-        command="build" if use_build_command else "run",
-        **kwargs,
-    ):
-        yield from _events_for_structured_json_line(
-            parsed_json_line, context, node_info_to_asset_key, runtime_metadata_fn, manifest_json
+        class CustomDbtManifest(DbtManifest):
+            @classmethod
+            def node_info_to_asset_key(cls, node_info: Mapping[str, Any]) -> AssetKey:
+                return node_info_to_asset_key(node_info)
+
+        cli_output = dbt_resource.cli(
+            args=["build" if use_build_command else "run", *build_command_args_from_flags(kwargs)],
+            manifest=CustomDbtManifest(raw_manifest=manifest_json),
         )
+        yield from cli_output.stream()
+
+
+class DbtOpConfig(PermissiveConfig):
+    """Keyword arguments to pass to the underlying dbt command. Additional arguments not listed in the schema will
+    be passed through as well, e.g. {'bool_flag': True, 'string_flag': 'hi'} will result in the flags
+    '--bool_flag --string_flag hi' being passed to the dbt command.
+    """
+
+    select: Optional[str] = None
+    exclude: Optional[str] = None
+    vars: Optional[Dict[str, Any]] = None
+    full_refresh: Optional[bool] = None
 
 
 def _get_dbt_op(
@@ -257,6 +303,7 @@ def _get_dbt_op(
     runtime_metadata_fn: Optional[
         Callable[[OpExecutionContext, Mapping[str, Any]], Mapping[str, RawMetadataValue]]
     ],
+    manifest_json: Mapping[str, Any],
 ):
     @op(
         name=op_name,
@@ -264,28 +311,17 @@ def _get_dbt_op(
         ins=ins,
         out=outs,
         required_resource_keys={dbt_resource_key},
-        config_schema=Field(
-            Permissive(
-                {
-                    "select": Field(str, is_required=False),
-                    "exclude": Field(str, is_required=False),
-                    "vars": Field(dict, is_required=False),
-                    "full_refresh": Field(bool, is_required=False),
-                }
-            ),
-            default_value={},
-            description=(
-                "Keyword arguments to pass to the underlying dbt command. Additional arguments not"
-                " listed in the schema will be passed through as well, e.g. {'bool_flag': True,"
-                " 'string_flag': 'hi'} will result in the flags '--bool-flag --string-flag hi'"
-                " being passed into the underlying execution"
-            ),
-        ),
     )
-    def _dbt_op(context):
-        dbt_resource = getattr(context.resources, dbt_resource_key)
-        # clean up any run results from the last run
-        dbt_resource.remove_run_results_json()
+    def _dbt_op(context, config: DbtOpConfig):
+        dbt_resource: Union[DbtCli, DbtCliClient] = getattr(context.resources, dbt_resource_key)
+        check.inst(
+            dbt_resource,
+            (DbtCli, DbtCliClient),
+            (
+                "Resource with key 'dbt_resource_key' must be a DbtCli or DbtCliClient object,"
+                f" but is a {type(dbt_resource)}"
+            ),
+        )
 
         kwargs: Dict[str, Any] = {}
         # in the case that we're running everything, opt for the cleaner selection string
@@ -313,8 +349,14 @@ def _get_dbt_op(
                 node_info_to_asset_key,
                 runtime_metadata_fn,
                 kwargs,
+                manifest_json=manifest_json,
             )
         else:
+            if not isinstance(dbt_resource, DbtCliClient):
+                check.failed(
+                    "Chose batch event iterator, but it only works with DbtCliClient, and"
+                    f" resource has type {type(dbt_resource)}"
+                )
             yield from _batch_event_iterator(
                 context,
                 dbt_resource,
@@ -334,6 +376,8 @@ def _dbt_nodes_to_assets(
     selected_unique_ids: AbstractSet[str],
     project_id: str,
     dbt_resource_key: str,
+    manifest_json: Mapping[str, Any],
+    op_name: Optional[str] = None,
     runtime_metadata_fn: Optional[
         Callable[[OpExecutionContext, Mapping[str, Any]], Mapping[str, RawMetadataValue]]
     ] = None,
@@ -346,6 +390,9 @@ def _dbt_nodes_to_assets(
     node_info_to_freshness_policy_fn: Callable[
         [Mapping[str, Any]], Optional[FreshnessPolicy]
     ] = default_freshness_policy_fn,
+    node_info_to_auto_materialize_policy_fn: Callable[
+        [Mapping[str, Any]], Optional[AutoMaterializePolicy]
+    ] = default_auto_materialize_policy_fn,
     node_info_to_definition_metadata_fn: Callable[
         [Mapping[str, Any]], Mapping[str, MetadataUserInput]
     ] = default_metadata_fn,
@@ -366,6 +413,7 @@ def _dbt_nodes_to_assets(
         asset_outs,
         group_names_by_key,
         freshness_policies_by_key,
+        auto_materialize_policies_by_key,
         fqns_by_output_name,
         _,
     ) = get_asset_deps(
@@ -374,15 +422,17 @@ def _dbt_nodes_to_assets(
         node_info_to_asset_key=node_info_to_asset_key,
         node_info_to_group_fn=node_info_to_group_fn,
         node_info_to_freshness_policy_fn=node_info_to_freshness_policy_fn,
+        node_info_to_auto_materialize_policy_fn=node_info_to_auto_materialize_policy_fn,
         node_info_to_definition_metadata_fn=node_info_to_definition_metadata_fn,
         io_manager_key=io_manager_key,
         display_raw_sql=display_raw_sql,
     )
 
     # prevent op name collisions between multiple dbt multi-assets
-    op_name = f"run_dbt_{project_id}"
-    if select != "*" or exclude:
-        op_name += "_" + hashlib.md5(select.encode() + exclude.encode()).hexdigest()[-5:]
+    if not op_name:
+        op_name = f"run_dbt_{project_id}"
+        if select != "fqn:*" or exclude:
+            op_name += "_" + hashlib.md5(select.encode() + exclude.encode()).hexdigest()[-5:]
 
     dbt_op = _get_dbt_op(
         op_name=op_name,
@@ -396,6 +446,7 @@ def _dbt_nodes_to_assets(
         node_info_to_asset_key=node_info_to_asset_key,
         partition_key_to_vars_fn=partition_key_to_vars_fn,
         runtime_metadata_fn=runtime_metadata_fn,
+        manifest_json=manifest_json,
     )
 
     return AssetsDefinition(
@@ -410,6 +461,7 @@ def _dbt_nodes_to_assets(
         asset_deps=asset_deps,
         group_names_by_key=group_names_by_key,
         freshness_policies_by_key=freshness_policies_by_key,
+        auto_materialize_policies_by_key=auto_materialize_policies_by_key,
         partitions_def=partitions_def,
     )
 
@@ -422,6 +474,7 @@ def load_assets_from_dbt_project(
     exclude: Optional[str] = None,
     key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
     source_key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
+    op_name: Optional[str] = None,
     runtime_metadata_fn: Optional[
         Callable[[OpExecutionContext, Mapping[str, Any]], Mapping[str, Any]]
     ] = None,
@@ -434,6 +487,9 @@ def load_assets_from_dbt_project(
     node_info_to_freshness_policy_fn: Callable[
         [Mapping[str, Any]], Optional[FreshnessPolicy]
     ] = default_freshness_policy_fn,
+    node_info_to_auto_materialize_policy_fn: Callable[
+        [Mapping[str, Any]], Optional[AutoMaterializePolicy]
+    ] = default_auto_materialize_policy_fn,
     node_info_to_definition_metadata_fn: Callable[
         [Mapping[str, Any]], Mapping[str, MetadataUserInput]
     ] = default_metadata_fn,
@@ -452,14 +508,14 @@ def load_assets_from_dbt_project(
         target_dir (Optional[str]): The target directory where dbt will place compiled artifacts.
             Defaults to "target" underneath the project_dir.
         select (Optional[str]): A dbt selection string for the models in a project that you want
-            to include. Defaults to "*".
+            to include. Defaults to `"fqn:*"`.
         exclude (Optional[str]): A dbt selection string for the models in a project that you want
             to exclude. Defaults to "".
-        key_prefix (Optional[Union[str, List[str]]]): A prefix to apply to all models in the dbt
-            project. Does not apply to sources.
-        dbt_resource_key (Optional[str]): The resource key that the dbt resource will be specified at. Defaults to "dbt".
-        source_key_prefix (Optional[Union[str, List[str]]]): A prefix to apply to all sources in the
-            dbt project. Does not apply to models.
+        key_prefix (Optional[Union[str, List[str]]]): A key prefix to apply to all assets loaded
+            from the dbt project. Does not apply to input assets.
+        source_key_prefix (Optional[Union[str, List[str]]]): A key prefix to apply to all input
+            assets for the set of assets loaded from the dbt project.
+        op_name (Optional[str]): Sets the name of the underlying Op that will generate the dbt assets.
         runtime_metadata_fn: (Optional[Callable[[SolidExecutionContext, Mapping[str, Any]], Mapping[str, Any]]]):
             A function that will be run after any of the assets are materialized and returns
             metadata entries for the asset, to be displayed in the asset catalog for that run.
@@ -486,6 +542,12 @@ def load_assets_from_dbt_project(
             `dagster_freshness_policy={"maximum_lag_minutes": 60, "cron_schedule": "0 9 * * *"}`
             will result in that model being assigned
             `FreshnessPolicy(maximum_lag_minutes=60, cron_schedule="0 9 * * *")`
+        node_info_to_auto_materialize_policy_fn (Dict[str, Any] -> Optional[AutoMaterializePolicy]):
+            A function that takes a dictionary of dbt node info and optionally returns a AutoMaterializePolicy
+            that should be applied to this node. By default, AutoMaterializePolicies will be created from
+            config applied to dbt models, i.e.:
+            `dagster_auto_materialize_policy={"type": "lazy"}` will result in that model being assigned
+            `AutoMaterializePolicy.lazy()`
         node_info_to_definition_metadata_fn (Dict[str, Any] -> Optional[Dict[str, MetadataUserInput]]):
             A function that takes a dictionary of dbt node info and optionally returns a dictionary
             of metadata to be attached to the corresponding definition. This is added to the default
@@ -493,13 +555,14 @@ def load_assets_from_dbt_project(
         display_raw_sql (Optional[bool]): [Experimental] A flag to indicate if the raw sql associated
             with each model should be included in the asset description. For large projects, setting
             this flag to False is advised to reduce the size of the resulting snapshot.
+        dbt_resource_key (Optional[str]): The resource key that the dbt resource will be specified at. Defaults to "dbt".
     """
     project_dir = check.str_param(project_dir, "project_dir")
     profiles_dir = check.opt_str_param(
         profiles_dir, "profiles_dir", os.path.join(project_dir, "config")
     )
     target_dir = check.opt_str_param(target_dir, "target_dir", os.path.join(project_dir, "target"))
-    select = check.opt_str_param(select, "select", "*")
+    select = check.opt_str_param(select, "select", "fqn:*")
     exclude = check.opt_str_param(exclude, "exclude", "")
 
     manifest_json, cli_output = _load_manifest_for_project(
@@ -514,6 +577,7 @@ def load_assets_from_dbt_project(
         exclude=exclude,
         key_prefix=key_prefix,
         source_key_prefix=source_key_prefix,
+        op_name=op_name,
         runtime_metadata_fn=runtime_metadata_fn,
         io_manager_key=io_manager_key,
         selected_unique_ids=selected_unique_ids,
@@ -521,6 +585,7 @@ def load_assets_from_dbt_project(
         use_build_command=use_build_command,
         partitions_def=partitions_def,
         partition_key_to_vars_fn=partition_key_to_vars_fn,
+        node_info_to_auto_materialize_policy_fn=node_info_to_auto_materialize_policy_fn,
         node_info_to_group_fn=node_info_to_group_fn,
         node_info_to_freshness_policy_fn=node_info_to_freshness_policy_fn,
         node_info_to_definition_metadata_fn=node_info_to_definition_metadata_fn,
@@ -535,6 +600,7 @@ def load_assets_from_dbt_manifest(
     exclude: Optional[str] = None,
     key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
     source_key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
+    op_name: Optional[str] = None,
     runtime_metadata_fn: Optional[
         Callable[[OpExecutionContext, Mapping[str, Any]], Mapping[str, Any]]
     ] = None,
@@ -548,6 +614,9 @@ def load_assets_from_dbt_manifest(
     node_info_to_freshness_policy_fn: Callable[
         [Mapping[str, Any]], Optional[FreshnessPolicy]
     ] = default_freshness_policy_fn,
+    node_info_to_auto_materialize_policy_fn: Callable[
+        [Mapping[str, Any]], Optional[AutoMaterializePolicy]
+    ] = default_auto_materialize_policy_fn,
     node_info_to_definition_metadata_fn: Callable[
         [Mapping[str, Any]], Mapping[str, MetadataUserInput]
     ] = default_metadata_fn,
@@ -563,13 +632,14 @@ def load_assets_from_dbt_manifest(
         manifest_json (Optional[Mapping[str, Any]]): The contents of a DBT manifest.json, which contains
             a set of models to load into assets.
         select (Optional[str]): A dbt selection string for the models in a project that you want
-            to include. Defaults to "*".
+            to include. Defaults to `"fqn:*"`.
         exclude (Optional[str]): A dbt selection string for the models in a project that you want
             to exclude. Defaults to "".
-        key_prefix (Optional[Union[str, List[str]]]): A prefix to apply to all models in the dbt
-            project. Does not apply to sources.
-        source_key_prefix (Optional[Union[str, List[str]]]): A prefix to apply to all sources in the
-            dbt project. Does not apply to models.
+        key_prefix (Optional[Union[str, List[str]]]): A key prefix to apply to all assets loaded
+            from the dbt project. Does not apply to input assets.
+        source_key_prefix (Optional[Union[str, List[str]]]): A key prefix to apply to all input
+            assets for the set of assets loaded from the dbt project.
+        op_name (Optional[str]): Sets the name of the underlying Op that will generate the dbt assets.
         dbt_resource_key (Optional[str]): The resource key that the dbt resource will be specified at. Defaults to "dbt".
         runtime_metadata_fn: (Optional[Callable[[SolidExecutionContext, Mapping[str, Any]], Mapping[str, Any]]]):
             A function that will be run after any of the assets are materialized and returns
@@ -598,6 +668,12 @@ def load_assets_from_dbt_manifest(
             `dagster_freshness_policy={"maximum_lag_minutes": 60, "cron_schedule": "0 9 * * *"}`
             will result in that model being assigned
             `FreshnessPolicy(maximum_lag_minutes=60, cron_schedule="0 9 * * *")`
+        node_info_to_auto_materialize_policy_fn (Dict[str, Any] -> Optional[AutoMaterializePolicy]):
+            A function that takes a dictionary of dbt node info and optionally returns a AutoMaterializePolicy
+            that should be applied to this node. By default, AutoMaterializePolicies will be created from
+            config applied to dbt models, i.e.:
+            `dagster_auto_materialize_policy={"type": "lazy"}` will result in that model being assigned
+            `AutoMaterializePolicy.lazy()`
         node_info_to_definition_metadata_fn (Dict[str, Any] -> Optional[Dict[str, MetadataUserInput]]):
             A function that takes a dictionary of dbt node info and optionally returns a dictionary
             of metadata to be attached to the corresponding definition. This is added to the default
@@ -636,7 +712,7 @@ def load_assets_from_dbt_manifest(
         )
         exclude = "" if exclude is None else exclude
     else:
-        select = select if select is not None else "*"
+        select = select if select is not None else "fqn:*"
         exclude = exclude if exclude is not None else ""
 
         selected_unique_ids = select_unique_ids_from_manifest(
@@ -653,6 +729,7 @@ def load_assets_from_dbt_manifest(
         exclude=exclude,
         selected_unique_ids=selected_unique_ids,
         dbt_resource_key=dbt_resource_key,
+        op_name=op_name,
         project_id=manifest_json["metadata"]["project_id"][:5],
         node_info_to_asset_key=node_info_to_asset_key,
         use_build_command=use_build_command,
@@ -660,8 +737,10 @@ def load_assets_from_dbt_manifest(
         partition_key_to_vars_fn=partition_key_to_vars_fn,
         node_info_to_group_fn=node_info_to_group_fn,
         node_info_to_freshness_policy_fn=node_info_to_freshness_policy_fn,
+        node_info_to_auto_materialize_policy_fn=node_info_to_auto_materialize_policy_fn,
         node_info_to_definition_metadata_fn=node_info_to_definition_metadata_fn,
         display_raw_sql=display_raw_sql,
+        manifest_json=manifest_json,
     )
     dbt_assets: Sequence[AssetsDefinition]
     if source_key_prefix:
@@ -679,5 +758,5 @@ def load_assets_from_dbt_manifest(
         dbt_assets = [dbt_assets_def]
 
     if key_prefix:
-        dbt_assets = prefix_assets(dbt_assets, key_prefix)
+        dbt_assets, _ = prefix_assets(dbt_assets, key_prefix, [], source_key_prefix)
     return dbt_assets
